summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--test/files/run/interpreter.scala16
1 files changed, 14 insertions, 2 deletions
diff --git a/test/files/run/interpreter.scala b/test/files/run/interpreter.scala
index bc04e56114..9b270f380a 100644
--- a/test/files/run/interpreter.scala
+++ b/test/files/run/interpreter.scala
@@ -90,14 +90,26 @@ def x => y => z
d="dd"
/></a>
-(1 + // give up early by typing two blank lines
+/*
+ /*
+ multi-line comment
+ */
+*/
+// multi-line string
+"""
+hello
+there
+"""
-</code>.text
+(1 + // give up early by typing two blank lines
+
+</code>.text
+
/** A writer that skips the first line of text. The first
* line of interpreter output is skipped because it includes
* a version number. */